"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
const client_ssm_1 = require("@aws-sdk/client-ssm");
const common_1 = require("@nestjs/common");
const common_2 = require("@nestjs/common");
const constant_1 = require("../../../shared/constant/config/constant");
let ParameterStoreService = class ParameterStoreService {
    constructor(client) {
        this.client = client;
    }
    /**
     * Retrieves parameters from AWS Parameter Store by the specified path.
     *
     * @param {string} path - The path to the parameters in AWS Parameter Store.
     * @param {boolean} decryptParameters - Whether to decrypt the parameter values. Default is false.
     * @param {boolean} recursiveLoading - Whether to recursively load parameters under the specified path. Default is false.
     * @param {boolean} verbose - Whether to log verbose messages. Default is false.
     * @returns {Promise<Array<Parameter>>} - A promise that resolves to an array of Parameter objects.
     */
    async getParametersByPath(path, decryptParameters = false, recursiveLoading = false, verbose = false) {
        if (verbose)
            common_2.Logger.verbose(`Getting parameters from path: ${path}`, "ParameterStoreConfig");
        let allParameters = [];
        let nextParametersToken;
        do {
            const getParameters = new client_ssm_1.GetParametersByPathCommand({
                NextToken: nextParametersToken,
                Path: path,
                Recursive: recursiveLoading,
                WithDecryption: decryptParameters,
            });
            const { NextToken, Parameters = [] } = await this.client.send(getParameters);
            allParameters = [...allParameters, ...Parameters];
            nextParametersToken = NextToken;
        } while (Boolean(nextParametersToken));
        if (verbose)
            common_2.Logger.verbose(`Found ${allParameters.length} parameters`, "ParameterStoreConfig");
        return allParameters;
    }
};
ParameterStoreService = __decorate([
    (0, common_1.Injectable)()
    // eslint-disable-next-line @elsikora/nestjs-typed/injectable-should-be-provided
    ,
    __param(0, (0, common_1.Inject)(constant_1.PARAMETER_STORE_SSM_CLIENT)),
    __metadata("design:paramtypes", [client_ssm_1.SSMClient])
], ParameterStoreService);
exports.default = ParameterStoreService;
//# sourceMappingURL=parameter-store.service.js.map