import type { DynamicModule } from "@nestjs/common";
import type { IParameterStoreConfigAsyncModuleProperties } from "../../shared/interface/config/async-module-properties.interface";
import type { IParameterStoreConfigProperties } from "../../shared/interface/config/properties.interface";
export declare class ParameterStoreConfigModule {
    /**
     * Registers the given options for dynamic module configuration.
     *
     * @param {IParameterStoreConfigProperties} options - The configuration options.
     * @return {DynamicModule} - The dynamic module configuration.
     */
    static register(options: IParameterStoreConfigProperties): DynamicModule;
    /**
     * Registers an asynchronous module in the application.
     *
     * @param {IParameterStoreConfigAsyncModuleProperties} properties - The properties for the async module.
     * @return {DynamicModule} - The registered dynamic module.
     */
    static registerAsync(properties: IParameterStoreConfigAsyncModuleProperties): DynamicModule;
    /**
     * Creates an async options provider for the given `properties` object.
     *
     * @param {IParameterStoreConfigAsyncModuleProperties} properties - The properties object used to configure the async options provider.
     * @returns {Provider} - The created async options provider.
     * @private
     */
    private static createAsyncOptionsProvider;
    /**
     * Creates an array of Providers for asynchronous module configuration using the given properties.
     *
     * @param {IParameterStoreConfigAsyncModuleProperties} properties - The properties for configuring the module asynchronously.
     *
     * @returns {Array<Provider>} An array of Providers for the module configuration.
     *
     * @private
     */
    private static createAsyncProviders;
}
